==> cosmo_1.0.tar.gz: cosmo/src/INCLUDE/fit.h <==
BOOLEAN fit(
	    DATASET *dataSet,     /* the dataset */
	    THETA *theta,         /* contains parameter estimates on exit */
	    int startNum,         /* index of starting value */
	    int nSitesNum,        /* index of candidate value for expected number of motif occurrences */
	    int width,            /* motif width */
	    int modTypeNum,       /* index of model type */
	    int conSetNum,        /* constraint set number */
	    int *excludeCv,       /* which groups are to be excluded in CV? */
	    int fold              /* number of CV groups altogether */
	    );

void initCrit(
	      CRIT *crit   /* pointer to struct to be initialized */
	      );

void copyCrit(
	      CRIT *from,   /* copy from this struct */
	      CRIT *to      /* to this struct */
	      );

BOOLEAN sameParms(
		  CRIT *crit1,   /* pointer to 1st struct */
		  CRIT *crit2
		  );

void selectModel(
		 DATASET *dataSet   /* the dataset */
		 );


void getSimpleCriteria(
		       DATASET *dataSet,  /* the dataset */
		       CRIT *crit         /* CRIT struct in which to enter the criterion values */
		       );

void getCvLikRisk(
		  DATASET *dataSet,    /* the dataset */
		  CRIT *crit,          /* criteria */
		  int fold             /* fold for CV */
		  );

void getCvPwmRisk(
		  DATASET *dataSet,   /* the dataset */
		  CRIT *crit          /* criteria */
		  );

BOOLEAN finalModel(
		   DATASET *dataSet  /* the dataset */
		   );

void createCvGroups(
		    SAMPLE* samples,          /* the samples that are to be divided up */
		    int numSeqs,              /* the number of samples */
		    int fold                  /* the number of groups that are to be created */
		    );

==> cosmo_1.6.0.tar.gz: cosmo/src/INCLUDE/fit.h <==
BOOLEAN fit(
	    DATASET *dataSet,     /* the dataset */
	    THETA *theta,         /* contains parameter estimates on exit */
	    int startNum,         /* index of starting value */
	    int nSitesNum,        /* index of candidate value for expected number of motif occurrences */
	    int width,            /* motif width */
	    int modTypeNum,       /* index of model type */
	    int conSetNum,        /* constraint set number */
	    SVSPACE *baseSvSpace  /* starting value space to use */
	    );

void initCrit(
	      CRIT *crit   /* pointer to struct to be initialized */
	      );

void copyCrit(
	      CRIT *from,   /* copy from this struct */
	      CRIT *to      /* to this struct */
	      );

BOOLEAN sameParms(
		  CRIT *crit1,   /* pointer to 1st struct */
		  CRIT *crit2
		  );

int selectModel(
		 DATASET *dataSet   /* the dataset */
		 );


void getSimpleCriteria(
		       DATASET *dataSet,    /* the dataset */
		       CRIT *crit,          /* CRIT struct in which to enter the criterion values */
		       SVSPACE *backSvSpace /* starting value space to use */
		       );

void getCvLikRisk(
		  DATASET *dataSet,    /* the dataset */
		  CRIT *crit,          /* criteria */
		  int fold,            /* fold for CV */
		  SVSPACE *backSvSpace /* starting value space to use */
		  );

void getCvPwmRisk(
		  DATASET *dataSet,   /* the dataset */
		  CRIT *crit          /* criteria */
		  );

BOOLEAN finalModel(
		   DATASET *dataSet  /* the dataset */
		   );

void createCvGroups(
		    SAMPLE* samples,          /* the samples that are to be divided up */
		    int numSeqs,              /* the number of samples */
		    int fold                  /* the number of groups that are to be created */
		    );
